diff src/fileio.c @ 7170:beb67ef38f88 v7.4.896

commit https://github.com/vim/vim/commit/b4f6a46b01ed00b642a2271e9d1559e51ab0f2c4 Author: Bram Moolenaar <Bram@vim.org> Date: Tue Oct 13 19:43:17 2015 +0200 patch 7.4.896 Problem: Editing a URL, which netrw should handle, doesn't work. Solution: Avoid changing slashes to backslashes. (Yasuhiro Matsumoto)
author Christian Brabandt <cb@256bit.org>
date Tue, 13 Oct 2015 19:45:05 +0200
parents bb44542231dc
children a34232b17763
line wrap: on
line diff
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -7547,7 +7547,8 @@ vim_tempname(extra_char, keep)
 
 #if defined(BACKSLASH_IN_FILENAME) || defined(PROTO)
 /*
  * Convert all backslashes in fname to forward slashes in-place.
  */
     void
 forward_slash(fname)
@@ -7555,6 +7556,8 @@ forward_slash(fname)
 {
     char_u	*p;
 
+    if (path_with_url(fname))
+	return;
     for (p = fname; *p != NUL; ++p)
 # ifdef  FEAT_MBYTE
 	/* The Big5 encoding can have '\' in the trail byte. */
@@ -7547,7 +7547,8 @@ vim_tempname(extra_char, keep)
 #if defined(BACKSLASH_IN_FILENAME) || defined(PROTO)
 /*
- * Convert all backslashes in fname to forward slashes in-place.
+ * Convert all backslashes in fname to forward slashes in-place, unless when
+ * it looks like a URL.
  */
     void